==================
What's New in v0.2
==================

New built-ins
-------------

* Added SN 2011fe Nearby Supernova Factory data to built-in models as
  ``'2011fe'``

New functions
-------------

Previously "experimental" functions now included:

* ``sncosmo.fit_lc`` (previously ``sncosmo.fit_model``)
* ``sncosmo.read_lc`` (previously ``sncosmo.readlc``)
* ``sncosmo.write_lc`` (previously ``sncosmo.writelc``)
* ``sncosmo.plot_lc`` (previously ``sncosmo.plotlc``)

Completely new functions:

* ``sncosmo.load_example_data``: Example photometric data.
* ``sncosmo.mcmc_lc``: Markov Chain Monte Carlo parameter estimation.
* ``sncosmo.animate_model``: Model animation using matplotlib.animation.

Fitting
-------

``sncosmo.fit_lc`` now uses the iminuit package for minimization by
default. This requires the iminuit package to be installed, but the
old minimizer (from scipy) can still be used by setting the keyword
``method='l-bfgs-b'``.

Plotting
--------

Ability to plot model synthetic photometry
without observed data, using the syntax::

    >>> sncosmo.plot_lc(model=model, bands=['band1', 'band2'])

Photometric data format
-----------------------

Photometric data format is now more flexible, allowing various names
for table columns.
